@@ -1,12 +1,12 @@
 /**
  * @file feed_parser.h  parsing of different feed formats
- * 
- * Copyright (C) 2008 Lars Windolf <lars.windolf@gmx.de>
+ *
+ * Copyright (C) 2008-2021 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version. 
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,23 +27,19 @@
 
 /** Holds all information used on feed parsing time */
 typedef struct feedParserCtxt {
-	subscriptionPtr	subscription;	/**< the subscription the feed belongs to (optional) */
-	feedPtr		feed;		/**< the feed structure to fill */
-	GList		*items;		/**< the list of new items */
-	struct item	*item;		/**< the item currently parsed (or NULL) */
+	subscriptionPtr	subscription;		/**< the subscription the feed belongs to (optional) */
+	feedPtr		feed;			/**< the feed structure to fill */
+	GList		*items;			/**< the list of new items */
+	struct item	*item;			/**< the item currently parsed (or NULL) */
 
-	GHashTable	*tmpdata;	/**< tmp data hash used during stateful parsing */
+	GHashTable	*tmpdata;		/**< tmp data hash used during stateful parsing */
 
-	gchar		*title;		/**< resulting feed/channel title */
+	gchar		*title;			/**< resulting feed/channel title */
 
-	gchar		*data;		/**< data buffer to parse */
-	gsize		dataLength;	/**< length of the data buffer */
-
-	xmlDocPtr	doc;		/**< the parsed data buffer */
-	gboolean	failed;		/**< TRUE if parsing failed because feed type could not be detected */
+	const gchar	*data;			/**< data buffer to parse */
+	gsize		dataLength;		/**< length of the data buffer */
 } *feedParserCtxtPtr;
 
-
 /**
  * Function type which parses the given feed data.
  *
@@ -64,17 +60,22 @@ typedef gboolean (*checkFormatFunc)	(xmlDocPtr doc, xmlNodePtr cur);
 
 /** feed handler interface */
 typedef struct feedHandler {
-	const gchar	*typeStr;	/**< string representation of the feed type */
-	feedParserFunc	feedParser;	/**< feed type parse function */
-	checkFormatFunc	checkFormat;	/**< Parser for the feed type*/
+	const gchar	*typeStr;		/**< string representation of the feed type */
+	feedParserFunc	feedParser;		/**< feed type parse function */
+	checkFormatFunc	checkFormat;		/**< Parser for the feed type*/
+	gboolean	html;			/**< TRUE if this is a HTML parser (as opposed tp XML feeds) */
 } *feedHandlerPtr;
 
 /**
  * Creates a new feed parsing context.
  *
+ * @subscription the feed's subscription
+ * @data         the feed data to parse
+ * @size         size of feed data
+ *
  * @returns a new feed parsing context
  */
-feedParserCtxtPtr feed_create_parser_ctxt (void);
+feedParserCtxtPtr feed_parser_ctxt_new (subscriptionPtr subscription, const gchar *data, gsize size);
 
 /**
  * Frees the given parser context. Note: it does
@@ -82,7 +83,7 @@ feedParserCtxtPtr feed_create_parser_ctxt (void);
  *
  * @param ctxt		the feed parsing context
  */
-void feed_free_parser_ctxt (feedParserCtxtPtr ctxt);
+void feed_parser_ctxt_free (feedParserCtxtPtr ctxt);
 
 /**
  * Lookup a feed type string from the feed type id.
@@ -104,11 +105,11 @@ const gchar *feed_type_fhp_to_str (feedHandlerPtr fhp);
 
 /**
  * General feed source parsing function. Parses the passed feed source
- * and tries to determine the source type. 
+ * and tries to determine the source type.
  *
  * @param ctxt		feed parsing context
  *
- * @returns FALSE if auto discovery is indicated, 
+ * @returns FALSE if auto discovery is indicated,
  *          TRUE if feed type was recognized
  */
 gboolean feed_parse (feedParserCtxtPtr ctxt);
