@@ -142,7 +142,7 @@ reedah_source_login (ReedahSourcePtr source, guint32 flags)
 
 	node_source_set_state (source->root, NODE_SOURCE_STATE_IN_PROGRESS);
 
-	update_execute_request (source, request, reedah_source_login_cb, source->root, flags);
+	update_execute_request (source, request, reedah_source_login_cb, source->root, flags | FEED_REQ_NO_FEED);
 }
 
 /* node source type implementation */
