@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2007-2021 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2009 Emilio Pozuelo Monfort <pochu27@gmail.com>
+ * Copyright (C) 2021 Lorenzo L. Ancora <admin@lorenzoancora.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +26,7 @@
 #include <libsoup/soup.h>
 #include <math.h>
 #include <string.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -86,7 +88,12 @@ network_process_callback (SoupSession *session, SoupMessage *msg, gpointer user_
 	debug1 (DEBUG_NET, "download status code: %d", msg->status_code);
 	debug1 (DEBUG_NET, "source after download: >>>%s<<<", job->result->source);
 
+#ifdef HAVE_G_MEMDUP2
+	job->result->data = g_memdup2 (msg->response_body->data, msg->response_body->length+1);
+#else
 	job->result->data = g_memdup (msg->response_body->data, msg->response_body->length+1);
+#endif
+
 	job->result->size = (size_t)msg->response_body->length;
 	debug1 (DEBUG_NET, "%d bytes downloaded", job->result->size);
 
@@ -324,9 +331,25 @@ network_init (void)
 	gchar		*filename;
 	SoupLogger	*logger;
 
-	/* Set an appropriate user agent,
-	 * e.g. "Liferea/1.10.0 (Linux; https://lzone.de/liferea/) AppleWebKit (KHTML, like Gecko)" */
-	useragent = g_strdup_printf ("Liferea/%s (%s; %s) AppleWebKit (KHTML, like Gecko)", VERSION, OSNAME, HOMEPAGE);
+	gchar const *sysua = g_getenv("LIFEREA_UA");
+	if(sysua == NULL) {
+		bool anonua = g_getenv("LIFEREA_UA_ANONYMOUS") != NULL;
+		if(anonua == false) {
+			/* Set an appropriate user agent,
+			 * e.g. "Liferea/1.10.0 (Linux; https://lzone.de/liferea/) AppleWebKit (KHTML, like Gecko)" */
+			useragent = g_strdup_printf ("Liferea/%s (%s; %s) AppleWebKit (KHTML, like Gecko)", VERSION, OSNAME, HOMEPAGE);
+		} else {
+			/* Set an anonymized, randomic user agent,
+			 * e.g. "Liferea/0.28.0 (https://lzone.de/liferea/) AppleWebKit (KHTML, like Gecko)" */
+			useragent = g_strdup_printf ("Liferea/%.2f.0 (%s) AppleWebKit (KHTML, like Gecko)", g_random_double(), HOMEPAGE);
+		}
+	} else {
+		/* Set an arbitrary user agent from the environment variable LIFEREA_UA */
+		useragent = g_strdup (sysua);
+	}
+	sysua = NULL;
+	g_assert_nonnull(useragent);
+	debug1 (DEBUG_NET, "HTTP/S user-agent set to \"%s\"", useragent);
 
 	/* Session cookies */
 	filename = common_create_config_filename ("session_cookies.txt");
@@ -338,13 +361,11 @@ network_init (void)
 						 SOUP_SESSION_TIMEOUT, 120,
 						 SOUP_SESSION_IDLE_TIMEOUT, 30,
 						 SOUP_SESSION_ADD_FEATURE, cookies,
-	                                         SOUP_SESSION_ADD_FEATURE_BY_TYPE, SOUP_TYPE_CONTENT_DECODER,
 						 NULL);
 	session2 = soup_session_new_with_options (SOUP_SESSION_USER_AGENT, useragent,
 						  SOUP_SESSION_TIMEOUT, 120,
 						  SOUP_SESSION_IDLE_TIMEOUT, 30,
 						  SOUP_SESSION_ADD_FEATURE, cookies,
-	                                          SOUP_SESSION_ADD_FEATURE_BY_TYPE, SOUP_TYPE_CONTENT_DECODER,
 						  SOUP_SESSION_PROXY_URI, NULL,
 						  SOUP_SESSION_PROXY_RESOLVER, NULL,
 						  NULL);
@@ -441,7 +462,7 @@ network_strerror (gint status)
 		case SOUP_STATUS_CANT_RESOLVE_PROXY:	tmp = _("Unable to resolve proxy host name"); break;
 		case SOUP_STATUS_CANT_CONNECT:		tmp = _("Unable to connect to remote host"); break;
 		case SOUP_STATUS_CANT_CONNECT_PROXY:	tmp = _("Unable to connect to proxy"); break;
-		case SOUP_STATUS_SSL_FAILED:		tmp = _("A network error occurred, or the other end closed the connection unexpectedly"); break;
+		case SOUP_STATUS_SSL_FAILED:		tmp = _("SSL/TLS negotiation failed. Possible outdated or unsupported encryption algorithm. Check your operating system settings."); break;
 
 		/* http 3xx redirection */
 		case SOUP_STATUS_MOVED_PERMANENTLY:	tmp = _("The resource moved permanently to a new location"); break;
@@ -477,4 +498,3 @@ network_strerror (gint status)
 
 	return tmp;
 }
-
