@@ -1,13 +1,13 @@
 /**
  * @file net.h  HTTP network access interface
- * 
- * Copyright (C) 2007-2009 Lars Windolf <lars.windolf@gmx.de>
+ *
+ * Copyright (C) 2007-2021 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2009 Emilio Pozuelo Monfort <pochu27@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version. 
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
+
 #ifndef _NET_H
 #define _NET_H
 
@@ -28,7 +28,7 @@
 
 /* Simple glue layer to abstract network code */
 
-/** 
+/**
  * Initialize HTTP client networking support.
  */
 void network_init (void);
@@ -78,7 +78,7 @@ const gchar * network_get_proxy_host (void);
 guint network_get_proxy_port (void);
 
 /**
- * Returns the currently configured proxy user name 
+ * Returns the currently configured proxy user name
  *
  * @returns the proxy user name (or NULL)
  */
@@ -96,16 +96,15 @@ const gchar * network_get_proxy_password (void);
  *
  * @param request	the update request
  */
-void network_process_request (const updateJobPtr const job);
+void network_process_request (const updateJobPtr job);
 
 /**
  * Returns explanation string for the given network error code.
  *
- * @param netstatus	network error status
- * @param httpstatus	HTTP status code
+ * @param status	libsoup status code
  *
  * @returns explanation string
  */
-const char * network_strerror (gint netstatus, gint httpstatus);
+const char * network_strerror (gint status);
 
 #endif
