@@ -1,7 +1,7 @@
 /*
  * @file liferea_htmlview.c  Liferea embedded HTML rendering
  *
- * Copyright (C) 2003-2015 Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2003-2021 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2005-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -36,12 +36,13 @@
 #include "enclosure.h"
 #include "feed.h"
 #include "feedlist.h"
+#include "itemlist.h"
 #include "net_monitor.h"
 #include "social.h"
 #include "render.h"
-#include "htmlview.h"
 #include "ui/browser_tabs.h"
 #include "ui/item_list_view.h"
+#include "ui/itemview.h"
 
 /* The LifereaHtmlView is a complex widget used to present both internally
    rendered content as well as serving as a browser widget. It automatically
@@ -60,16 +61,19 @@ struct _LifereaHtmlView {
 	GObject	parent_instance;
 
 	GtkWidget	*renderWidget;		/*<< The HTML widget (e.g. Webkit widget) */
-	GtkWidget	*container;			/*<< Outer container including render widget and toolbar */
-	GtkWidget	*toolbar;			/*<< The navigation toolbar */
+	GtkWidget	*container;		/*<< Outer container including render widget and toolbar */
+	GtkWidget	*toolbar;		/*<< The navigation toolbar */
 
-	GtkWidget	*forward;			/*<< The forward button */
-	GtkWidget	*back;				/*<< The back button */
-	GtkWidget	*urlentry;			/*<< The URL entry widget */
+	GtkWidget	*forward;		/*<< The forward button */
+	GtkWidget	*back;			/*<< The back button */
+	GtkWidget	*urlentry;		/*<< The URL entry widget */
 	browserHistory	*history;		/*<< The browser history */
 
-	gboolean	internal;			/*<< TRUE if internal view presenting generated HTML with special links */
+	gboolean	internal;		/*<< TRUE if internal view presenting generated HTML with special links */
 	gboolean	forceInternalBrowsing;	/*<< TRUE if clicked links should be force loaded in a new tab (regardless of global preference) */
+	gboolean	readerMode;		/*<< TRUE if Readability.js is to be used */
+
+	gchar 		*content;		/*<< current HTML content (excluding decorations, content passed to Readability.js) */
 
 	htmlviewImplPtr impl;			/*<< Browser widget support implementation */
 };
@@ -144,6 +148,7 @@ liferea_htmlview_finalize (GObject *object)
 
 	browser_history_free (htmlview->history);
 	g_clear_object (&htmlview->container);
+	g_free (htmlview->content);
 
 	g_signal_handlers_disconnect_by_data (network_monitor_get (), object);
 }
@@ -226,7 +231,9 @@ liferea_htmlview_init (LifereaHtmlView *htmlview)
 {
 	GtkWidget *widget, *image;
 
+	htmlview->content = NULL;
 	htmlview->internal = FALSE;
+	htmlview->readerMode = FALSE;
 	htmlview->impl = htmlview_get_impl ();
 	htmlview->renderWidget = RENDERER (htmlview)->create (htmlview);
 	htmlview->container = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -301,6 +308,8 @@ liferea_htmlview_new (gboolean forceInternalBrowsing)
 	htmlview = LIFEREA_HTMLVIEW (g_object_new (LIFEREA_HTMLVIEW_TYPE, NULL));
 	htmlview->forceInternalBrowsing = forceInternalBrowsing;
 
+	conf_get_bool_value (ENABLE_READER_MODE, &(htmlview->readerMode));
+
 	liferea_htmlview_clear (htmlview);
 
 	g_signal_connect (network_monitor_get (), "online-status-changed",
@@ -360,32 +369,15 @@ liferea_htmlview_clear (LifereaHtmlView *htmlview)
 	liferea_htmlview_write (htmlview, "<html><body></body></html>", NULL);
 }
 
-static gboolean
-liferea_htmlview_is_special_url (const gchar *url)
-{
-	/* match against all special protocols, simple
-	   convention: all have to start with "liferea-" */
-	if (url == strstr (url, "liferea-"))
-		return TRUE;
-
-	return FALSE;
-}
-
 struct internalUriType {
 	const gchar	*suffix;
 	void		(*func)(itemPtr item);
 };
 
-static struct internalUriType internalUriTypes[] = {
-	{ "refresh-comments",	comments_refresh },
-	{ NULL,			NULL }
-};
-
 void
 liferea_htmlview_on_url (LifereaHtmlView *htmlview, const gchar *url)
 {
-	if (!liferea_htmlview_is_special_url (url))
-		g_signal_emit_by_name (htmlview, "statusbar-changed", url);
+	g_signal_emit_by_name (htmlview, "statusbar-changed", url);
 }
 
 void
@@ -423,10 +415,40 @@ liferea_htmlview_location_changed (LifereaHtmlView *htmlview, const gchar *locat
 	g_signal_emit_by_name (htmlview, "location-changed", location);
 }
 
+void
+liferea_htmlview_load_finished (LifereaHtmlView *htmlview, const gchar *location)
+{
+	/*
+	    Add Readability.js handling
+	    - for external content: if user chose so
+	    - for internal content: always (Readability is enable on demand here)
+	 */
+	if (htmlview->readerMode || (location == strstr (location, "liferea://"))) {
+		g_autoptr(GBytes) b1 = NULL, b2 = NULL;
+
+		// Return Readability.js and Liferea specific loader code
+		b1 = g_resources_lookup_data ("/org/gnome/liferea/readability/Readability.js", 0, NULL);
+		b2 = g_resources_lookup_data ("/org/gnome/liferea/htmlview.js", 0, NULL);
+
+		g_assert(b1 != NULL);
+		g_assert(b2 != NULL);
+
+		// FIXME: pass actual content here too, instead of on render_item()!
+		// this safe us from the trouble to have JS enabled earlier!
+
+		debug1 (DEBUG_GUI, "Enabling reader mode for '%s'", location);
+		(RENDERER (htmlview)->run_js) (htmlview->renderWidget,
+		                               g_strdup_printf ("%s\n%s\nloadContent(%s, '%s');\n",
+		                                                (gchar *)g_bytes_get_data (b1, NULL),
+		                                                (gchar *)g_bytes_get_data (b2, NULL),
+		                                                (htmlview->readerMode?"true":"false"),
+		                                                htmlview->content));
+	}
+}
+
 gboolean
 liferea_htmlview_handle_URL (LifereaHtmlView *htmlview, const gchar *url)
 {
-	struct internalUriType	*uriType;
 	gboolean browse_inside_application;
 
 	g_return_val_if_fail (htmlview, TRUE);
@@ -439,48 +461,8 @@ liferea_htmlview_handle_URL (LifereaHtmlView *htmlview, const gchar *url)
 	        htmlview->forceInternalBrowsing?"true":"false",
 		htmlview->internal?"true":"false");
 
-	/* first catch all links with special URLs... */
-	if (liferea_htmlview_is_special_url (url)) {
-		if (htmlview->internal) {
-
-			/* it is a generic item list URI type */
-			uriType = internalUriTypes;
-			while (uriType->suffix) {
-				if (!strncmp (url + strlen ("liferea-"), uriType->suffix, strlen (uriType->suffix))) {
-					gchar *nodeid, *itemnr;
-					nodeid = strstr (url, "://");
-					if (nodeid) {
-						nodeid += 3;
-						itemnr = strchr (nodeid, '-');
-						if (itemnr) {
-							itemPtr item;
-
-							*itemnr = 0;
-							itemnr++;
-
-							item = item_load (atol (itemnr));
-							if (item) {
-								(*uriType->func) (item);
-								item_unload (item);
-							} else {
-								g_warning ("Fatal: no item with id (node=%s, item=%s) found!!!", nodeid, itemnr);
-							}
-
-							return TRUE;
-						}
-					}
-				}
-				uriType++;
-			}
-			g_warning ("Internal error: unhandled protocol in URL \"%s\"!", url);
-		} else {
-			g_warning ("Security: Prevented external HTML document to use internal link scheme (%s)!", url);
-		}
-		return TRUE;
-	}
-
 	if(htmlview->forceInternalBrowsing || browse_inside_application) {
-		return FALSE;
+		liferea_htmlview_launch_URL_internal (htmlview, url);
 	} else {
 		(void)browser_launch_URL_external (url);
 	}
@@ -491,6 +473,8 @@ liferea_htmlview_handle_URL (LifereaHtmlView *htmlview, const gchar *url)
 void
 liferea_htmlview_launch_URL_internal (LifereaHtmlView *htmlview, const gchar *url)
 {
+	/* Reset any intermediate reader mode change via htmlview context menu */
+	conf_get_bool_value (ENABLE_READER_MODE, &(htmlview->readerMode));
 
 	gtk_widget_set_sensitive (htmlview->forward, browser_history_can_go_forward (htmlview->history));
 	gtk_widget_set_sensitive (htmlview->back,    browser_history_can_go_back (htmlview->history));
@@ -512,6 +496,20 @@ liferea_htmlview_get_zoom (LifereaHtmlView *htmlview)
 	return (RENDERER (htmlview)->zoomLevelGet) (htmlview->renderWidget);
 }
 
+void
+liferea_htmlview_set_reader_mode (LifereaHtmlView *htmlview, gboolean readerMode)
+{
+	htmlview->readerMode = readerMode;
+
+	(RENDERER (htmlview)->reload) (htmlview->renderWidget);
+}
+
+gboolean
+liferea_htmlview_get_reader_mode (LifereaHtmlView *htmlview)
+{
+	return htmlview->readerMode;
+}
+
 void
 liferea_htmlview_scroll (LifereaHtmlView *htmlview)
 {
@@ -530,8 +528,98 @@ liferea_htmlview_do_zoom (LifereaHtmlView *htmlview, gint zoom)
 
 }
 
-void
-liferea_htmlview_update_style_element (LifereaHtmlView *htmlview)
+static void
+liferea_htmlview_start_output (GString *buffer,
+                               const gchar *base)
 {
-	(RENDERER (htmlview)->reloadStyle) (htmlview->renderWidget);
+	/* Prepare HTML boilderplate */
+	g_string_append (buffer, "<!DOCTYPE html>\n");
+	g_string_append (buffer, "<html>\n");
+	g_string_append (buffer, "<head>\n<title>HTML View</title>");
+
+	// FIXME: consider adding CSP meta tag here as e.g. Firefox reader mode page does
+	g_string_append (buffer, "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />");
+
+	if (base) {
+		gchar *escBase = g_markup_escape_text (base, -1);
+		g_string_append (buffer, "<base href=\"");
+		g_string_append (buffer, escBase);
+		g_string_append (buffer, "\" />\n");
+		g_free (escBase);
+	}
+
+	g_string_append (buffer, "</head><body>Loading...</body></html>");
+}
+
+void
+liferea_htmlview_update (LifereaHtmlView *htmlview, guint mode)
+{
+	GString		*output;
+	nodePtr		node = NULL;
+	itemPtr		item = NULL;
+	gchar		*baseURL = NULL;
+	gchar		*content = NULL;
+
+	/* determine base URL */
+	switch (mode) {
+		case ITEMVIEW_SINGLE_ITEM:
+			item = itemlist_get_selected ();
+			if(item) {
+				baseURL = (gchar *)node_get_base_url (node_from_id (item->nodeId));
+				item_unload (item);
+			}
+			break;
+		case ITEMVIEW_NODE_INFO:
+			node = feedlist_get_selected ();
+			if (!node)
+				return;
+			baseURL = (gchar *) node_get_base_url (node);
+			break;
+	}
+
+	if (baseURL)
+		baseURL = g_markup_escape_text (baseURL, -1);
+
+	output = g_string_new (NULL);
+	liferea_htmlview_start_output (output, baseURL);
+
+	switch (mode) {
+		case ITEMVIEW_SINGLE_ITEM:
+			item = itemlist_get_selected ();
+			if (item) {
+				content = item_render (item, mode);
+				item_unload (item);
+			}
+			break;
+		case ITEMVIEW_NODE_INFO:
+			if (node)
+				content = node_render (node);
+			break;
+		default:
+			g_warning ("HTML view: invalid viewing mode!!!");
+			break;
+	}
+
+	g_free (htmlview->content);
+	htmlview->content = NULL;
+
+	if (content) {
+		/* URI escape our content for safe transfer to Readability.js
+		   URI escaping is needed for UTF-8 conservation and for JS stringification */
+		htmlview->content = g_uri_escape_string (content, NULL, TRUE);
+		g_free (content);
+	} else {
+		htmlview->content = g_uri_escape_string ("", NULL, TRUE);
+	}
+
+	debug1 (DEBUG_HTML, "writing %d bytes to HTML view", strlen (output->str));
+	liferea_htmlview_write (htmlview, output->str, baseURL);
+	g_string_free (output, TRUE);
+	g_free (baseURL);
+}
+
+void
+liferea_htmlview_update_stylesheet (LifereaHtmlView *htmlview)
+{
+	(RENDERER (htmlview)->setStylesheet) (htmlview->renderWidget);
 }
