@@ -37,7 +37,6 @@
 #include "debug.h"
 #include "export.h"
 #include "feedlist.h"
-#include "htmlview.h"
 #include "item_history.h"
 #include "itemlist.h"
 #include "liferea_application.h"
@@ -1310,13 +1309,15 @@ liferea_shell_create (GtkApplication *app, const gchar *overrideWindowState, gin
 	gtk_widget_set_sensitive (GTK_WIDGET (shell->feedlistViewWidget), TRUE);
 
 	/* 10.) After main window is realized get theme colors and set up feed
- 	        list and tray icon */
+		list and load WebView stylesheet */
 	render_init_theme_colors (GTK_WIDGET (shell->window));
 
 	shell->feedlist = feedlist_create (feedListView);
 	g_signal_connect (shell->feedlist, "new-items",
 	                  G_CALLBACK (liferea_shell_update_unread_stats), shell->feedlist);
 
+	itemview_style_update ();
+
 	/* 11.) Restore latest selection */
 
 	// FIXME: Move to feed list code
@@ -1424,7 +1425,6 @@ void
 liferea_shell_rebuild_css (void)
 {
 	render_init_theme_colors (GTK_WIDGET (shell->window));
-	render_get_css(TRUE);
 	itemview_style_update ();
 }
 
