@@ -2,6 +2,7 @@
  * @file liferea_web_view.c  Webkit2 widget for Liferea
  *
  * Copyright (C) 2016 Leiaz <leiaz@mailbox.org>
+ * Copyright (C) 2021 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -143,6 +144,7 @@ liferea_web_view_on_menu (WebKitWebView 	*view,
 {
 	GtkWidget 		*menu;
 	GMenu 			*menu_model,*section;
+	GMenuItem		*menu_item = NULL;
 	gchar			*image_uri = NULL;
 	gchar			*link_uri = NULL;
 	gchar			*link_title = NULL;
@@ -171,7 +173,6 @@ liferea_web_view_on_menu (WebKitWebView 	*view,
 	/* and now add all we want to see */
 	if (link) {
 		gchar *path;
-		GMenuItem *menu_item;
 
 		menu_add_item (section, _("Open Link In _Tab"), "app.open-link-in-tab", link_uri);
 		menu_add_item (section, _("Open Link In Browser"), "app.open-link-in-browser", link_uri);
@@ -219,6 +220,12 @@ liferea_web_view_on_menu (WebKitWebView 	*view,
 		g_menu_append (section, _("_Decrease Text Size"), "liferea_web_view.zoom-out");
 	}
 
+	g_menu_append_section (menu_model, NULL, G_MENU_MODEL (section));
+	g_object_unref (section);
+	section = g_menu_new ();
+
+	g_menu_append (section, _("_Reader Mode"), "liferea_web_view.toggle-reader-mode");
+
 	g_menu_append_section (menu_model, NULL, G_MENU_MODEL (section));
 	g_object_unref (section);
 	g_free (link_uri);
@@ -282,13 +289,25 @@ on_popup_webinspector_activate (GSimpleAction *action, GVariant *parameter, gpoi
 	webkit_web_inspector_show (WEBKIT_WEB_INSPECTOR(inspector));
 }
 
+static void
+on_popup_toggle_reader_mode_activate (GSimpleAction *action, GVariant *parameter, gpointer user_data)
+{
+	WebKitWebView *webview = WEBKIT_WEB_VIEW (user_data);
+	gboolean reader = g_variant_get_boolean (parameter);
+
+g_warning("Change reader mode");
+	liferea_htmlview_set_reader_mode (g_object_get_data (G_OBJECT (webview), "htmlview"), reader);
+	g_simple_action_set_state (action, g_variant_new_boolean (reader));
+}
+
 static const GActionEntry liferea_web_view_gaction_entries[] = {
 	{"save-link", on_popup_save_link_activate, "s", NULL, NULL},
 	{"subscribe-link", on_popup_subscribe_link_activate, "s", NULL, NULL},
 	{"copy-selection", on_popup_copy_activate, NULL, NULL, NULL},
 	{"zoom-in", on_popup_zoomin_activate, NULL, NULL, NULL},
 	{"zoom-out", on_popup_zoomout_activate, NULL, NULL, NULL},
-	{"web-inspector", on_popup_webinspector_activate, NULL, NULL, NULL}
+	{"web-inspector", on_popup_webinspector_activate, NULL, NULL, NULL},
+	{"toggle-reader-mode", NULL, NULL, "true", on_popup_toggle_reader_mode_activate}
 };
 
 static void
@@ -583,7 +602,7 @@ liferea_web_view_create_web_view (WebKitWebView *view, WebKitNavigationAction *a
 }
 
 static void
-liferea_webkit_load_status_changed (WebKitWebView *view, WebKitLoadEvent event, gpointer user_data)
+liferea_web_view_load_status_changed (WebKitWebView *view, WebKitLoadEvent event, gpointer user_data)
 {
 	LifereaHtmlView	*htmlview;
 	gboolean isFullscreen;
@@ -601,6 +620,18 @@ liferea_webkit_load_status_changed (WebKitWebView *view, WebKitLoadEvent event,
 			htmlview = g_object_get_data (G_OBJECT (view), "htmlview");
 			liferea_htmlview_location_changed (htmlview, webkit_web_view_get_uri (view));
 			break;
+		case WEBKIT_LOAD_FINISHED:
+			htmlview = g_object_get_data (G_OBJECT (view), "htmlview");
+
+			GActionGroup 	*action_group;
+			action_group = LIFEREA_WEB_VIEW (view)->menu_action_group;
+			GSimpleAction *reader_action;
+			reader_action = G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (action_group), "toggle-reader-mode"));
+			gboolean reader = liferea_htmlview_get_reader_mode(htmlview);
+			g_simple_action_set_state (reader_action, g_variant_new_boolean (reader));
+
+			liferea_htmlview_load_finished (htmlview, webkit_web_view_get_uri (view));
+			break;
 		default:
 			break;
 	}
@@ -631,7 +662,6 @@ liferea_web_view_init(LifereaWebView *self)
 	g_action_map_add_action_entries (G_ACTION_MAP(self->menu_action_group), liferea_web_view_gaction_entries, G_N_ELEMENTS (liferea_web_view_gaction_entries), self);
 	gtk_widget_insert_action_group (GTK_WIDGET (self), "liferea_web_view", self->menu_action_group);
 
-
 	g_signal_connect (
 		self,
 		"notify::title",
@@ -677,7 +707,7 @@ liferea_web_view_init(LifereaWebView *self)
 	g_signal_connect (
 		self,
 		"load-changed",
-		G_CALLBACK (liferea_webkit_load_status_changed),
+		G_CALLBACK (liferea_web_view_load_status_changed),
 		NULL
 	);
 }
