@@ -2,7 +2,7 @@
  * @file webkit.c  WebKit2 browser module for Liferea
  *
  * Copyright (C) 2016-2019 Leiaz <leiaz@mailbox.org>
- * Copyright (C) 2007-2010 Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2007-2021 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2008 Lars Strojny <lars@strojny.net>
  * Copyright (C) 2009-2012 Emilio Pozuelo Monfort <pochu27@gmail.com>
  * Copyright (C) 2009 Adrian Bunk <bunk@users.sourceforge.net>
@@ -30,6 +30,7 @@
 #include "conf.h"
 #include "common.h"
 #include "enclosure.h" /* Only for enclosure_download */
+#include "render.h"
 #include "ui/browser_tabs.h"
 #include "ui/liferea_htmlview.h"
 
@@ -48,9 +49,6 @@
 typedef struct _LifereaWebKitImpl {
 	GObject parent;
 
-	WebKitSettings 	*settings;		/**< settings object used for rendering headlines */
-	WebKitSettings	*settings_extern;	/**< settings object used for tabs and external content  */
-
 	GDBusServer 	*dbus_server;
 	GList 		*dbus_connections;
 } LifereaWebKitImpl;
@@ -61,6 +59,9 @@ typedef struct _LifereaWebKitImplClass {
 
 G_DEFINE_TYPE (LifereaWebKitImpl, liferea_webkit_impl, G_TYPE_OBJECT)
 
+// singleton
+LifereaWebKitImpl *impl = NULL;
+
 enum {
 	PAGE_CREATED_SIGNAL,
 	N_SIGNALS
@@ -73,7 +74,6 @@ liferea_webkit_impl_dispose (GObject *gobject)
 {
 	LifereaWebKitImpl *self = LIFEREA_WEBKIT_IMPL(gobject);
 
-	g_object_unref (self->settings);
 	g_clear_object (&self->dbus_server);
 	g_list_free_full (self->dbus_connections, g_object_unref);
 
@@ -107,7 +107,7 @@ liferea_webkit_impl_class_init (LifereaWebKitImplClass *klass)
 static LifereaWebKitImpl *
 liferea_webkit_impl_new (void)
 {
-	return g_object_new (LIFEREA_TYPE_WEBKIT_IMPL,NULL);
+	return g_object_new (LIFEREA_TYPE_WEBKIT_IMPL, NULL);
 }
 
 /**
@@ -409,7 +409,7 @@ liferea_webkit_handle_liferea_scheme (WebKitURISchemeRequest *request, gpointer
 static void
 liferea_webkit_impl_init (LifereaWebKitImpl *self)
 {
-	gboolean	disable_javascript, enable_plugins, enable_itp;
+	gboolean	enable_itp;
 	WebKitSecurityManager *security_manager;
 	WebKitWebsiteDataManager *website_data_manager;
 	self->dbus_connections = NULL;
@@ -420,36 +420,6 @@ liferea_webkit_impl_init (LifereaWebKitImpl *self)
 	website_data_manager = webkit_web_context_get_website_data_manager (webkit_web_context_get_default ());
 	webkit_security_manager_register_uri_scheme_as_local (security_manager, "liferea");
 
-	/* Note: we manage 2 webkit settings here, one for headline display
-	   where Javascript is always on as we use Readability.js and another
-	   setting for tabs where Javascript can be toggled using the preferences */
-
-	self->settings        = webkit_settings_new ();
-	self->settings_extern = webkit_settings_new ();
-
-	conf_get_bool_value (DISABLE_JAVASCRIPT, &disable_javascript);
-	g_object_set (self->settings,        "enable-javascript", TRUE, NULL);
-	g_object_set (self->settings_extern, "enable-javascript", !disable_javascript, NULL);
-
-	conf_get_bool_value (ENABLE_PLUGINS, &enable_plugins);
-	g_object_set (self->settings,        "enable-plugins", FALSE, NULL);
-	g_object_set (self->settings_extern, "enable-plugins", enable_plugins, NULL);
-
-	webkit_settings_set_user_agent_with_application_details (self->settings,        "Liferea", VERSION);
-	webkit_settings_set_user_agent_with_application_details (self->settings_extern, "Liferea", VERSION);
-
-	conf_signal_connect (
-		"changed::" DISABLE_JAVASCRIPT,
-		G_CALLBACK (liferea_webkit_disable_javascript_cb),
-		self->settings_extern
-	);
-
-	conf_signal_connect (
-		"changed::" ENABLE_PLUGINS,
-		G_CALLBACK (liferea_webkit_enable_plugins_cb),
-		self->settings_extern
-	);
-
 	conf_signal_connect (
 		"changed::" ENABLE_ITP,
 		G_CALLBACK (liferea_webkit_enable_itp_cb),
@@ -505,12 +475,6 @@ liferea_webkit_write_html (
 	const gchar *content_type
 )
 {
-	// Switch to internal setting, that assure JS is enabled
-	webkit_web_view_set_settings (
-		WEBKIT_WEB_VIEW (webview),
-		liferea_webkit_impl->settings
-	);
-
 	// FIXME Avoid doing a copy ?
 	GBytes *string_bytes = g_bytes_new (string, length);
 	/* Note: we explicitely ignore the passed base URL
@@ -527,30 +491,42 @@ liferea_webkit_write_html (
 	g_bytes_unref (string_bytes);
 }
 
+static void
+liferea_webkit_run_js (GtkWidget *widget, gchar *js)
+{
+	// No matter what was before we need JS now
+	g_object_set (webkit_web_view_get_settings (WEBKIT_WEB_VIEW (widget)), "enable-javascript", TRUE, NULL);
+
+	webkit_web_view_run_javascript (WEBKIT_WEB_VIEW (widget),
+	                                js,
+	                                NULL,
+	                                NULL,
+	                                NULL);
+	g_free (js);
+}
+
 static void
 liferea_webkit_set_font_size (GtkWidget *widget, gpointer user_data)
 {
-	gchar	*font;
-	guint	fontSize;
+	WebKitSettings	*settings = WEBKIT_SETTINGS(user_data);
+	gchar		*font;
+	guint		fontSize;
 
 	if (!gtk_widget_get_realized (widget))
 		return;
 
 	font = webkit_get_font (&fontSize);
 	if (font) {
-		g_object_set (liferea_webkit_impl->settings,        "default-font-family", font, NULL);
-		g_object_set (liferea_webkit_impl->settings_extern, "default-font-family", font, NULL);
+		g_object_set (settings,        "default-font-family", font, NULL);
 
 		fontSize = normalize_font_size (fontSize, widget);
-		g_object_set (liferea_webkit_impl->settings,        "default-font-size", fontSize, NULL);
-		g_object_set (liferea_webkit_impl->settings_extern, "default-font-size", fontSize, NULL);
+		g_object_set (settings,        "default-font-size", fontSize, NULL);
 
 		g_free (font);
 	}
 
 	fontSize = normalize_font_size (7, widget);
-	g_object_set (liferea_webkit_impl->settings,        "minimum-font-size", fontSize, NULL);
-	g_object_set (liferea_webkit_impl->settings_extern, "minimum-font-size", fontSize, NULL);
+	g_object_set (settings,        "minimum-font-size", fontSize, NULL);
 }
 
 static void
@@ -559,6 +535,34 @@ liferea_webkit_screen_changed (GtkWidget *widget, GdkScreen *previous_screen, gp
 	liferea_webkit_set_font_size (widget, user_data);
 }
 
+/**
+ * Reset settings to safe preferences
+ */
+static void
+liferea_webkit_default_settings (WebKitSettings *settings)
+{
+	gboolean	disable_javascript, enable_plugins;
+
+	conf_get_bool_value (DISABLE_JAVASCRIPT, &disable_javascript);
+	g_object_set (settings, "enable-javascript", !disable_javascript, NULL);
+
+	conf_get_bool_value (ENABLE_PLUGINS, &enable_plugins);
+	g_object_set (settings, "enable-plugins", enable_plugins, NULL);
+
+	webkit_settings_set_user_agent_with_application_details (settings, "Liferea", VERSION);
+
+	conf_signal_connect (
+		"changed::" DISABLE_JAVASCRIPT,
+		G_CALLBACK (liferea_webkit_disable_javascript_cb),
+		settings
+	);
+	conf_signal_connect (
+		"changed::" ENABLE_PLUGINS,
+		G_CALLBACK (liferea_webkit_enable_plugins_cb),
+		settings
+	);
+}
+
 /**
  * Initializes WebKit
  *
@@ -568,10 +572,13 @@ static GtkWidget *
 liferea_webkit_new (LifereaHtmlView *htmlview)
 {
 	WebKitWebView 	*view;
+	WebKitSettings	*settings;
 
 	view = WEBKIT_WEB_VIEW (liferea_web_view_new ());
 
-	webkit_web_view_set_settings (view, liferea_webkit_impl->settings);
+	settings = webkit_settings_new ();
+	liferea_webkit_default_settings (settings);
+	webkit_web_view_set_settings (view, settings);
 
 	g_signal_connect_object (
 		liferea_webkit_impl,
@@ -588,7 +595,7 @@ liferea_webkit_new (LifereaHtmlView *htmlview)
 	);
 
 	g_signal_connect (G_OBJECT (view), "screen_changed", G_CALLBACK (liferea_webkit_screen_changed), NULL);
-	g_signal_connect (G_OBJECT (view), "realize", G_CALLBACK (liferea_webkit_set_font_size), NULL);
+	g_signal_connect (G_OBJECT (view), "realize", G_CALLBACK (liferea_webkit_set_font_size), settings);
 
 	gtk_widget_show (GTK_WIDGET (view));
 	return GTK_WIDGET (view);
@@ -609,11 +616,9 @@ liferea_webkit_launch_url (GtkWidget *webview, const gchar *url)
 		http_url = g_strdup (url);
 	}
 
-	// Switch to extern settings (that might allow JS, depending on preferences
-	webkit_web_view_set_settings (
-		WEBKIT_WEB_VIEW (webview),
-		liferea_webkit_impl->settings_extern
-	);
+	// Force preference JS settings when launching external URL
+	// needed, because we might be switching from internal reader mode
+	liferea_webkit_default_settings (webkit_web_view_get_settings (WEBKIT_WEB_VIEW (webview)));
 
 	webkit_web_view_load_uri (
 		WEBKIT_WEB_VIEW (webview),
@@ -713,12 +718,36 @@ liferea_webkit_set_proxy (ProxyDetectMode mode, const gchar *host, guint port, c
 }
 
 /**
- * Execute JS Function in WebView to reload the stylesheet
+ * Load liferea.css via user style sheet
  */
 static void
-liferea_webkit_reload_style (GtkWidget *webview)
+liferea_webkit_set_style (GtkWidget *webview)
 {
-    webkit_web_view_run_javascript (WEBKIT_WEB_VIEW (webview), "updateStyle();", NULL, NULL, NULL);
+	if (render_get_css () == NULL)
+		return;
+
+	WebKitUserContentManager *manager = webkit_web_view_get_user_content_manager (WEBKIT_WEB_VIEW (webview));
+
+	webkit_user_content_manager_remove_all_style_sheets (manager);
+
+	WebKitUserStyleSheet *stylesheet = webkit_user_style_sheet_new (render_get_css(),
+		WEBKIT_USER_CONTENT_INJECT_ALL_FRAMES,
+		WEBKIT_USER_STYLE_LEVEL_USER,
+		NULL,
+		NULL);
+	webkit_user_content_manager_add_style_sheet (manager, stylesheet);
+	webkit_user_style_sheet_unref (stylesheet);
+}
+
+/**
+ * Reload the current contents of webview
+ */
+static void
+liferea_webkit_reload (GtkWidget *webview)
+{
+	liferea_webkit_default_settings (webkit_web_view_get_settings (WEBKIT_WEB_VIEW (webview)));
+
+	webkit_web_view_reload (webview);
 }
 
 static struct
@@ -726,6 +755,7 @@ htmlviewImpl webkitImpl = {
 	.init		= liferea_webkit_init,
 	.create		= liferea_webkit_new,
 	.write		= liferea_webkit_write_html,
+	.run_js		= liferea_webkit_run_js,
 	.launch		= liferea_webkit_launch_url,
 	.zoomLevelGet	= liferea_webkit_get_zoom_level,
 	.zoomLevelSet	= liferea_webkit_change_zoom_level,
@@ -734,7 +764,8 @@ htmlviewImpl webkitImpl = {
 	.scrollPagedown	= liferea_webkit_scroll_pagedown,
 	.setProxy	= liferea_webkit_set_proxy,
 	.setOffLine	= NULL, // FIXME: blocked on https://bugs.webkit.org/show_bug.cgi?id=18893
-	.reloadStyle	= liferea_webkit_reload_style
+	.setStylesheet	= liferea_webkit_set_style,
+	.reload		= liferea_webkit_reload
 };
 
 DECLARE_HTMLVIEW_IMPL (webkitImpl);
